==> charcoal-0.6.0.zip: charcoal-0.6.0/charcoal/classes/core/ClassUtil.class.php <==
<?php
/**
* 饹˴ؤ桼ƥƥ
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class ClassUtil
{
	/*
	 * 饹̾򸡾
	 */
	public static function validateClassName( String $class_name )
	{
//		return preg_match( "/\A[a-zA-Z]\w*/", "$class_name" );
		$class_name = "$class_name";

		return TRUE;
	}

	/*
	 * 饹
	 */
	public static function loadClass( $class_path, $class_name )
	{
		// ѥ̤
		if ( !$class_path ){
			return FALSE;
		}

		// ʤ㳰򥹥
/*
		$include_path_list = explode( PATH_SEPARATOR, get_include_path() );
		$found = FALSE;
		foreach( $include_path_list as $include_path ){
			$path = $include_path . DIRECTORY_SEPARATOR . $class_path;
			if ( is_file($path) ){
				$found = TRUE;
				break;
			}
		}
		if ( !$found ){
			$msg = "Source file path[$class_path] is not file";
			require_once( 'exceptions/ClassNotFoundException.class.php' );
			throw new ClassNotFoundException($class_name,$class_path,$msg);
		}
*/
		// ɤ߹
		require( $class_path );

		// 饹̤ʤ㳰򥹥
/*
		if ( !class_exists($class_name,FALSE) && !interface_exists($class_name,FALSE) ){
			$msg = "Class[$class_name] is not defined in source file[$class_path]";
			require_once( 'exceptions/ClassNotFoundException.class.php' );
			throw new ClassNotFoundException($class_name,$class_path,$msg);
		}
*/

		return TRUE;
	}

	/*
	 * 饹Υ󥹥󥹤
	 */
	public static function newInstance( String $class_name, $args = NULL )
	{
		log_info( "system",  "ClassUtil#newInstance($class_name)", __FILE__, __LINE__ );

		$class_name = $class_name->getValue();
/*
		if ( !class_exists($class_name) ){
			throw new ClassNotFoundException( $class_name );
		}
*/
/*
		$reflection = new ReflectionClass( $class_name );

		if ( !$args ){
			$instance = $reflection->newInstance( NULL );
		}
		else if ( is_array($args) ){
			switch ( count($args) ){
			case 0:		$instance = $reflection->newInstance( NULL );															break;
			case 1:		$instance = $reflection->newInstance( $args[0] );														break;
			case 2:		$instance = $reflection->newInstance( $args[0], $args[1] );												break;
			case 3:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2] );									break;
			case 4:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2], $args[3] );							break;
			case 5:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2], $args[3], $args[4] );				break;
			case 6:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2], $args[3], $args[4], $args[5] );		break;
			}
		}
		else{
			$instance = $reflection->newInstance( $args );
		}
*/

		$class_name = "$class_name";
		if ( !$args ){
			$instance = new $class_name();
		}
		else if ( is_array($args) ){
			switch ( count($args) ){
			case 0:		$instance = new $class_name( NULL );															break;
			case 1:		$instance = new $class_name( $args[0] );														break;
			case 2:		$instance = new $class_name( $args[0], $args[1] );												break;
			case 3:		$instance = new $class_name( $args[0], $args[1], $args[2] );									break;
			case 4:		$instance = new $class_name( $args[0], $args[1], $args[2], $args[3] );							break;
			case 5:		$instance = new $class_name( $args[0], $args[1], $args[2], $args[3], $args[4] );				break;
			case 6:		$instance = new $class_name( $args[0], $args[1], $args[2], $args[3], $args[4], $args[5] );		break;
			}
		}
		else{
			$instance = new $class_name( $args );
		}

		return $instance;
	}

	/*
	 * 饹󥿥եƤ뤫ǧ
	 */
	public static function testImplements( $object, $interface_name )
	{
		return ( $object instanceof $interface_name );
	}

}

==> charcoal-0.7.0.zip: charcoal-0.7.0/charcoal/classes/core/ClassUtil.class.php <==
<?php
/**
* 饹˴ؤ桼ƥƥ
*
* PHP version 5
*
* @package    core
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

class ClassUtil
{
	/*
	 * 饹̾򸡾
	 */
	public static function validateClassName( String $class_name )
	{
//		return preg_match( "/\A[a-zA-Z]\w*/", "$class_name" );
		$class_name = "$class_name";

		return TRUE;
	}

	/*
	 * 饹
	 */
	public static function loadClass( $class_path, $class_name )
	{
		// ѥ̤
		if ( !$class_path ){
			return FALSE;
		}

		// ʤ㳰򥹥
/*
		$include_path_list = explode( PATH_SEPARATOR, get_include_path() );
		$found = FALSE;
		foreach( $include_path_list as $include_path ){
			$path = $include_path . DIRECTORY_SEPARATOR . $class_path;
			if ( is_file($path) ){
				$found = TRUE;
				break;
			}
		}
		if ( !$found ){
			$msg = "Source file path[$class_path] is not file";
			require_once( 'exceptions/ClassNotFoundException.class.php' );
			throw new ClassNotFoundException($class_name,$class_path,$msg);
		}
*/
		// ɤ߹
		$path = require( $class_path );

		// 饹̤ʤ㳰򥹥
/*
		if ( !class_exists($class_name,FALSE) && !interface_exists($class_name,FALSE) ){
			$msg = "Class[$class_name] is not defined in source file[$class_path]";
			require_once( 'exceptions/ClassNotFoundException.class.php' );
			throw new ClassNotFoundException($class_name,$class_path,$msg);
		}
*/


		return TRUE;
	}

	/*
	 * 饹Υ󥹥󥹤
	 */
	public static function newInstance( String $class_name, $args = NULL )
	{
		log_info( "system",  "ClassUtil#newInstance($class_name)", __FILE__, __LINE__ );

		$class_name = $class_name->getValue();
/*
		if ( !class_exists($class_name) ){
			throw new ClassNotFoundException( $class_name );
		}
*/
/*
		$reflection = new ReflectionClass( $class_name );

		if ( !$args ){
			$instance = $reflection->newInstance( NULL );
		}
		else if ( is_array($args) ){
			switch ( count($args) ){
			case 0:		$instance = $reflection->newInstance( NULL );															break;
			case 1:		$instance = $reflection->newInstance( $args[0] );														break;
			case 2:		$instance = $reflection->newInstance( $args[0], $args[1] );												break;
			case 3:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2] );									break;
			case 4:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2], $args[3] );							break;
			case 5:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2], $args[3], $args[4] );				break;
			case 6:		$instance = $reflection->newInstance( $args[0], $args[1], $args[2], $args[3], $args[4], $args[5] );		break;
			}
		}
		else{
			$instance = $reflection->newInstance( $args );
		}
*/

		$class_name = "$class_name";
		if ( !$args ){
			$instance = new $class_name();
		}
		else if ( is_array($args) ){
			switch ( count($args) ){
			case 0:		$instance = new $class_name( NULL );															break;
			case 1:		$instance = new $class_name( $args[0] );														break;
			case 2:		$instance = new $class_name( $args[0], $args[1] );												break;
			case 3:		$instance = new $class_name( $args[0], $args[1], $args[2] );									break;
			case 4:		$instance = new $class_name( $args[0], $args[1], $args[2], $args[3] );							break;
			case 5:		$instance = new $class_name( $args[0], $args[1], $args[2], $args[3], $args[4] );				break;
			case 6:		$instance = new $class_name( $args[0], $args[1], $args[2], $args[3], $args[4], $args[5] );		break;
			}
		}
		else{
			$instance = new $class_name( $args );
		}

		return $instance;
	}

	/*
	 * 饹󥿥եƤ뤫ǧ
	 */
	public static function testImplements( $object, $interface_name )
	{
		return ( $object instanceof $interface_name );
	}

}
return __FILE__;
